@@ -1,11 +1,7 @@
-/*
- * $Id: mt.h,v 1.00 2002/02/08 19:22:46 ams Exp $
- * Copyright 2001 Abhijit Menon-Sen <ams@wiw.org>
- */
+#ifndef _MATH_MT_H_
+#define _MATH_MT_H_
 
-#include <stdlib.h>
-
-#if defined(__linux__) || defined(__WIN32__)
+#if defined(__linux__) || defined(__WIN32__) || defined(__GLIBC__)
 #include <stdint.h>
 #elif defined(__osf__)
 #include <inttypes.h>
@@ -13,10 +9,6 @@
 #include <sys/types.h>
 #endif
 
-#ifndef _MATH_MT_H_
-#define _MATH_MT_H_
-
-/* Period parameters */
 enum { N = 624, M = 397 };
 
 struct mt {
